@@ -2,7 +2,7 @@ package App::Monport;
 use strict;
 use App::Cmd::Setup -app;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =for HTML <a href="https://travis-ci.org/jreisinger/App-Monport"><img src="https://travis-ci.org/jreisinger/App-Monport.svg?branch=master"></a>
 
@@ -43,7 +43,7 @@ To check regularly create a cronjob like:
 
  PERL5LIB=/home/jdoe/perl5/lib/perl5
 
- * 21 * * 5 /home/jdoe/perl5/bin/monport diff --name "test scan" --email jdoe@example.com
+ 07 21 * * 5 /home/jdoe/perl5/bin/monport diff --name "test scan" --email jdoe@example.com
 
 To list the executed base scans:
 
